# Changelog

## [v2.0.3](https://github.com/GENESIS-EFRC/reaction-network/tree/v2.0.3) (2021-08-05)

[Full Changelog](https://github.com/GENESIS-EFRC/reaction-network/compare/v2.0.2...v2.0.3)

**Merged pull requests:**

- Update README and trigger release [\#34](https://github.com/GENESIS-EFRC/reaction-network/pull/34) ([shyamd](https://github.com/shyamd))

## [v2.0.2](https://github.com/GENESIS-EFRC/reaction-network/tree/v2.0.2) (2021-08-05)

[Full Changelog](https://github.com/GENESIS-EFRC/reaction-network/compare/v2.0.1...v2.0.2)

**Merged pull requests:**

- Bug fix for interdependent reactions [\#33](https://github.com/GENESIS-EFRC/reaction-network/pull/33) ([mattmcdermott](https://github.com/mattmcdermott))

## [v2.0.1](https://github.com/GENESIS-EFRC/reaction-network/tree/v2.0.1) (2021-08-05)

[Full Changelog](https://github.com/GENESIS-EFRC/reaction-network/compare/v2.0.0...v2.0.1)

**Merged pull requests:**

- Fix and deploy docs [\#32](https://github.com/GENESIS-EFRC/reaction-network/pull/32) ([shyamd](https://github.com/shyamd))

## [v2.0.0](https://github.com/GENESIS-EFRC/reaction-network/tree/v2.0.0) (2021-08-05)

[Full Changelog](https://github.com/GENESIS-EFRC/reaction-network/compare/paper...v2.0.0)

**Merged pull requests:**

- Major refactor of entire reaction-network package [\#23](https://github.com/GENESIS-EFRC/reaction-network/pull/23) ([mattmcdermott](https://github.com/mattmcdermott))

## [paper](https://github.com/GENESIS-EFRC/reaction-network/tree/paper) (2021-04-15)

[Full Changelog](https://github.com/GENESIS-EFRC/reaction-network/compare/v1.0...paper)

**Merged pull requests:**

- Merging of major revision reaction-network code [\#5](https://github.com/GENESIS-EFRC/reaction-network/pull/5) ([mattmcdermott](https://github.com/mattmcdermott))
- Repo Cleanup [\#4](https://github.com/GENESIS-EFRC/reaction-network/pull/4) ([shyamd](https://github.com/shyamd))

## [v1.0](https://github.com/GENESIS-EFRC/reaction-network/tree/v1.0) (2020-07-21)

[Full Changelog](https://github.com/GENESIS-EFRC/reaction-network/compare/e55a689a4076416b181324eabb8066566c3c3a8e...v1.0)

**Merged pull requests:**

- Added pathway balancing, NIST gas data, StructuralComplexity cost metric, and more. [\#3](https://github.com/GENESIS-EFRC/reaction-network/pull/3) ([mattmcdermott](https://github.com/mattmcdermott))
- Implemented Gibbs Free Energy SISSO descriptor  [\#2](https://github.com/GENESIS-EFRC/reaction-network/pull/2) ([mattmcdermott](https://github.com/mattmcdermott))
- Added refactoring and documentation [\#1](https://github.com/GENESIS-EFRC/reaction-network/pull/1) ([mattmcdermott](https://github.com/mattmcdermott))



\* *This Changelog was automatically generated by [github_changelog_generator](https://github.com/github-changelog-generator/github-changelog-generator)*
